@@ -103,9 +103,9 @@ eos
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
-          { :manila_dashboard_package_name => 'python3-manila-dashboard' }
+          { :manila_dashboard_package_name => 'python3-manila-ui' }
         when 'RedHat'
           { :manila_dashboard_package_name => 'openstack-manila-ui' }
         end
