@@ -23,28 +23,13 @@ describe 'horizon' do
             :tag    => ['openstack', 'horizon-package'],
           )
       }
-      it { is_expected.to contain_exec('refresh_horizon_django_cache').with({
-          :command     => '/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear',
-          :refreshonly => true,
-      })}
-      it { is_expected.to contain_exec('refresh_horizon_django_compress').with({
-          :command     => '/usr/share/openstack-dashboard/manage.py compress --force',
-          :refreshonly => true,
-      })}
-      it {
-        if facts[:os]['family'] == 'RedHat'
-          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
-          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
-        else
-          is_expected.to_not contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
-          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
-        end
 
+      it {
         is_expected.to contain_concat(platforms_params[:config_file]).with(
           :mode      => '0640',
           :owner     => platforms_params[:wsgi_user],
           :group     => platforms_params[:wsgi_group],
-          :show_diff => false
+          :show_diff => false,
         )
       }
 
@@ -62,25 +47,15 @@ describe 'horizon' do
       it 'generates local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = False',
-          "LOGIN_URL = '#{platforms_params[:root_url]}/auth/login/'",
-          "LOGOUT_URL = '#{platforms_params[:root_url]}/auth/logout/'",
-          "LOGIN_REDIRECT_URL = '#{platforms_params[:root_url]}/'",
           "ALLOWED_HOSTS = ['foo.example.com', ]",
           'HORIZON_CONFIG["password_autocomplete"] = "off"',
-          "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
+          "SECRET_KEY = secret_key.generate_or_read_from_file('#{platforms_params[:secret_key_file]}')",
           'OPENSTACK_KEYSTONE_URL = "http://127.0.0.1:5000"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "member"',
-          "    'can_set_mount_point': True,",
-          "    'can_set_password': False,",
-          "    'enable_distributed_router': False,",
-          "    'enable_ha_router': False,",
-          "    'enable_quotas': True,",
-          "    'enable_security_group': True,",
-          'API_RESULT_LIMIT = 1000',
-          'API_RESULT_PAGE_SIZE = 20',
-          'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
           "            'handlers': ['file'],",
+          'SESSION_TIMEOUT = 3600',
+          'TOKEN_TIMEOUT_MARGIN = 0',
           'COMPRESS_OFFLINE = True',
           "FILE_UPLOAD_TEMP_DIR = '/tmp'",
         ])
@@ -92,6 +67,15 @@ describe 'horizon' do
         expect(content).not_to match(/^SESSION_ENGINE/)
       end
 
+      it 'creates a key file' do
+        is_expected.to contain_file(platforms_params[:secret_key_file]).with(
+          :mode      => '0600',
+          :content   => 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0',
+          :owner     => platforms_params[:wsgi_user],
+          :group     => platforms_params[:wsgi_group],
+          :show_diff => false,
+        )
+      end
       it { is_expected.not_to contain_file('/tmp') }
     end
 
@@ -99,6 +83,7 @@ describe 'horizon' do
       before do
         params.merge!({
           :cache_backend                    => 'django.core.cache.backends.memcached.MemcachedCache',
+          :cache_timeout                    => 300,
           :cache_options                    => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
           :cache_server_ip                  => '10.0.0.1',
           :django_session_engine            => 'django.contrib.sessions.backends.cache',
@@ -131,6 +116,7 @@ describe 'horizon' do
           :keystone_default_domain          => 'domain.tld',
           :overview_days_range              => 1,
           :session_timeout                  => 1800,
+          :token_timeout_margin             => 60,
           :timezone                         => 'Asia/Shanghai',
           :available_themes                 => [
             { 'name' => 'default', 'label' => 'Default', 'path' => 'themes/default' },
@@ -159,43 +145,50 @@ describe 'horizon' do
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
           'HORIZON_CONFIG["password_autocomplete"] = "on"',
-          "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
           "        'OPTIONS': {",
           "            'DEAD_RETRY': 1,",
           "            'SERVER_RETRIES': 1,",
           "            'SOCKET_TIMEOUT': 1,",
           "        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',",
           "        'LOCATION': '10.0.0.1:11211',",
+          "        'TIMEOUT': 300,",
           'SESSION_ENGINE = "django.contrib.sessions.backends.cache"',
           'OPENSTACK_KEYSTONE_URL = "https://keystone.example.com:4682"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "SwiftOperator"',
           'OPENSTACK_SSL_NO_VERIFY = True',
-          "OPENSTACK_KEYSTONE_BACKEND = {",
+          'from openstack_dashboard.settings import OPENSTACK_KEYSTONE_BACKEND',
+          'OPENSTACK_KEYSTONE_BACKEND.update({',
           "    'name': 'native',",
           "    'can_edit_user': True,",
           "    'can_edit_group': True,",
           "    'can_edit_project': True,",
           "    'can_edit_domain': False,",
           "    'can_edit_role': False,",
-          "}",
+          'from openstack_dashboard.settings import OPENSTACK_HYPERVISOR_FEATURES',
+          'OPENSTACK_HYPERVISOR_FEATURES.update({',
           "    'can_set_mount_point': False,",
           "    'can_set_password': True,",
+          'from openstack_dashboard.settings import OPENSTACK_CINDER_FEATURES',
+          'OPENSTACK_CINDER_FEATURES.update({',
           "    'enable_backup': True,",
+          'from openstack_dashboard.settings import OPENSTACK_NEUTRON_NETWORK',
+          'OPENSTACK_NEUTRON_NETWORK.update({',
           "    'default_ipv4_subnet_pool_label': None,",
           "    'enable_quotas': False,",
           "    'enable_security_group': False,",
+          "    'enable_distributed_router': False,",
+          "    'enable_ha_router': False,",
           "    'supported_provider_types': ['flat', 'vxlan'],",
           "    'supported_vnic_types': ['*'],",
           'OPENSTACK_ENABLE_PASSWORD_RETRIEVE = True',
-          'CREATE_IMAGE_DEFAULTS = {',
+          'from openstack_dashboard.settings import CREATE_IMAGE_DEFAULTS',
+          'CREATE_IMAGE_DEFAULTS.update({',
           "    'image_visibility': 'private',",
-          "    'config_drive': False,",
           "    'create_volume': False,",
           "    'disable_image': True,",
           "    'disable_instance_snapshot': True,",
           "    'disable_volume': True,",
           "    'disable_volume_snapshot': True,",
-          "    'enable_scheduler_hints': True,",
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
           'OPENSTACK_KEYSTONE_ENDPOINT_TYPE = "public"',
@@ -203,24 +196,24 @@ describe 'horizon' do
           'API_RESULT_PAGE_SIZE = 40',
           'DROPDOWN_MAX_ITEMS = 123',
           'TIME_ZONE = "Asia/Shanghai"',
-          "AVAILABLE_THEMES = [",
+          'AVAILABLE_THEMES = [',
           "    ('default', 'Default', 'themes/default'),",
           "    ('material', 'Material', 'themes/material'),",
-          "]",
+          ']',
           "DEFAULT_THEME = 'default'",
           "            'level': 'DEBUG',",
           "            'handlers': ['console', 'syslog'],",
-          "SESSION_TIMEOUT = 1800",
+          'SESSION_TIMEOUT = 1800',
+          'TOKEN_TIMEOUT_MARGIN = 60',
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
-          "OVERVIEW_DAYS_RANGE = 1",
+          'OVERVIEW_DAYS_RANGE = 1',
           'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
       it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
-      it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
-      it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
+      it { is_expected.to_not contain_exec('refresh_horizon_django_compress') }
 
       it { is_expected.to contain_file(params[:file_upload_temp_dir]) }
     end
@@ -237,9 +230,6 @@ describe 'horizon' do
           "        'LOCATION': [ '10.0.0.1:11211','10.0.0.2:11211', ],",
         ])
       end
-
-      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
-      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'with overridden parameters, IPv6 cache_server_ip array and MemcachedCache' do
@@ -256,9 +246,6 @@ describe 'horizon' do
           "        'LOCATION': [ 'inet6:[fd12:3456:789a:1::1]:11211','inet6:[fd12:3456:789a:1::2]:11211', ],",
         ])
       end
-
-      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
-      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'with overridden parameters, IPv6 cache_server_ip array and PyMemcacheCache' do
@@ -275,9 +262,6 @@ describe 'horizon' do
           "        'LOCATION': [ '[fd12:3456:789a:1::1]:11211','[fd12:3456:789a:1::2]:11211', ],",
         ])
       end
-
-      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
-      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'with overridden parameters and cache_server_url (string)' do
@@ -292,9 +276,6 @@ describe 'horizon' do
           "        'LOCATION': 'redis://:password@10.0.0.1:6379/1',",
         ])
       end
-
-      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
-      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'with overridden parameters and cache_server_url (array)' do
@@ -309,9 +290,6 @@ describe 'horizon' do
           "        'LOCATION': ['192.0.2.1:11211','192.0.2.2:11211'],",
         ])
       end
-
-      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
-      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'installs python memcache library when cache_backend is set to memcache' do
@@ -613,7 +591,7 @@ describe 'horizon' do
 
       it 'enforce_password_check is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          'HORIZON_CONFIG["enforce_password_check"] = True',
+          'ENFORCE_PASSWORD_CHECK = True',
         ])
       end
     end
@@ -736,17 +714,29 @@ describe 'horizon' do
   end
 
   shared_examples_for 'horizon on RedHat' do
+    it 'skips refreshing horizon django cache' do
+      is_expected.to_not contain_exec('refresh_horizon_django_compress')
+    end
+
     it 'sets WEBROOT in local_settings.py' do
       verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-        "WEBROOT = '/dashboard/'",
+        "WEBROOT = '/dashboard'",
       ])
     end
   end
 
   shared_examples_for 'horizon on Debian' do
+    it 'refreshes horizon django cache' do
+      is_expected.to contain_exec('refresh_horizon_django_compress').with({
+        :command     => '/usr/share/openstack-dashboard/manage.py compress --force',
+        :refreshonly => true,
+      })
+      is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
+    end
+
     it 'sets WEBROOT in local_settings.py' do
       verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-        "WEBROOT = '/horizon/'",
+        "WEBROOT = '/horizon'",
       ])
     end
   end
@@ -765,6 +755,7 @@ describe 'horizon' do
           if facts[:os]['name'] == 'Debian'
             { :config_file        => '/etc/openstack-dashboard/local_settings.py',
               :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
+              :secret_key_file    => '/etc/openstack-dashboard/.secret_key_store',
               :package_name       => 'openstack-dashboard-apache',
               :root_url           => '/horizon',
               :root_path          => '/var/lib/openstack-dashboard',
@@ -776,6 +767,7 @@ describe 'horizon' do
           else
             { :config_file        => '/etc/openstack-dashboard/local_settings.py',
               :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
+              :secret_key_file    => '/etc/openstack-dashboard/.secret_key_store',
               :package_name       => 'openstack-dashboard',
               :root_url           => '/horizon',
               :root_path          => '/var/lib/openstack-dashboard',
@@ -788,6 +780,7 @@ describe 'horizon' do
         when 'RedHat'
           { :config_file        => '/etc/openstack-dashboard/local_settings',
             :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
+            :secret_key_file    => '/etc/openstack-dashboard/.secret_key_store',
             :package_name       => 'openstack-dashboard',
             :root_url           => '/dashboard',
             :root_path          => '/usr/share/openstack-dashboard',
